[SeaBIOS] [PATCH] remove iasl-generated hex files from git repo

Kevin O'Connor kevin at koconnor.net
Thu May 31 03:39:46 CEST 2012


On Fri, May 25, 2012 at 03:07:40PM +0200, Gerd Hoffmann wrote:
> Almost every linux distro has iasl packaged these days.
> Lets make it a build dependency and stop the hassle we
> have with updating the *.hex files in the git repo.

I agree with the patch, but I'd prefer not to complicate the Makefile
any further.  How about the following instead?

-Kevin


>From 51d6ba3e6fac2e78679145fe34f3861225670ae9 Mon Sep 17 00:00:00 2001
From: Kevin O'Connor <kevin at koconnor.net>
Date: Wed, 30 May 2012 21:31:42 -0400
Subject: [PATCH] remove iasl-generated hex files from git repo
To: seabios at seabios.org

Almost every linux distro has iasl packaged these days.
Lets make it a build dependency and stop the hassle we
have with updating the *.hex files in the git repo.

Signed-off-by: Gerd Hoffmann <kraxel at redhat.com>
Signed-off-by: Kevin O'Connor <kevin at koconnor.net>
---
 Makefile                             |   14 +-
 src/acpi-dsdt.hex                    | 4387 ----------------------------------
 src/ssdt-pcihp.hex                   | 1672 -------------
 src/ssdt-proc.hex                    |  134 --
 tools/{test-gcc.sh => test-build.sh} |   15 +-
 5 files changed, 21 insertions(+), 6201 deletions(-)
 delete mode 100644 src/acpi-dsdt.hex
 delete mode 100644 src/ssdt-pcihp.hex
 delete mode 100644 src/ssdt-proc.hex
 rename tools/{test-gcc.sh => test-build.sh} (90%)

diff --git a/Makefile b/Makefile
index 7d01652..5f3740d 100644
--- a/Makefile
+++ b/Makefile
@@ -81,10 +81,10 @@ vpath %.S src vgasrc
 
 ################ Common build rules
 
-# Verify the gcc configuration and test if -fwhole-program works.
-TESTGCC:=$(shell CC="$(CC)" LD="$(LD)" tools/test-gcc.sh)
+# Verify the build environment works.
+TESTGCC:=$(shell CC="$(CC)" LD="$(LD)" IASL="$(IASL)" tools/test-build.sh)
 ifeq "$(TESTGCC)" "-1"
-$(error "Please upgrade GCC and/or binutils")
+$(error "Please upgrade the build environment")
 endif
 
 ifndef COMPSTRAT
@@ -220,15 +220,15 @@ $(OUT)vgabios.bin: $(OUT)vgabios.bin.raw tools/buildrom.py
 
 ################ DSDT build rules
 
-src/%.hex: src/%.dsl ./tools/acpi_extract_preprocess.py ./tools/acpi_extract.py
-	@echo "Compiling DSDT"
+$(OUT)%.hex: src/%.dsl ./tools/acpi_extract_preprocess.py ./tools/acpi_extract.py
+	@echo "  Compiling IASL $@"
 	$(Q)cpp -P $< > $(OUT)$*.dsl.i.orig
 	$(Q)$(PYTHON) ./tools/acpi_extract_preprocess.py $(OUT)$*.dsl.i.orig > $(OUT)$*.dsl.i
-	$(Q)$(IASL) -l -tc -p $(OUT)$* $(OUT)$*.dsl.i
+	$(Q)$(IASL) -vs -l -tc -p $(OUT)$* $(OUT)$*.dsl.i
 	$(Q)$(PYTHON) ./tools/acpi_extract.py $(OUT)$*.lst > $(OUT)$*.off
 	$(Q)cat $(OUT)$*.off > $@
 
-$(OUT)ccode32flat.o: src/acpi-dsdt.hex src/ssdt-proc.hex src/ssdt-pcihp.hex
+$(OUT)ccode32flat.o: $(OUT)acpi-dsdt.hex $(OUT)ssdt-proc.hex $(OUT)ssdt-pcihp.hex
 
 ################ Kconfig rules
 
diff --git a/src/acpi-dsdt.hex b/src/acpi-dsdt.hex
deleted file mode 100644
index a4af597..0000000
diff --git a/src/ssdt-pcihp.hex b/src/ssdt-pcihp.hex
deleted file mode 100644
index b15ad5a..0000000
diff --git a/src/ssdt-proc.hex b/src/ssdt-proc.hex
deleted file mode 100644
index a28172e..0000000
diff --git a/tools/test-gcc.sh b/tools/test-build.sh
similarity index 90%
rename from tools/test-gcc.sh
rename to tools/test-build.sh
index 05bae29..7d36ae8 100755
--- a/tools/test-gcc.sh
+++ b/tools/test-build.sh
@@ -1,5 +1,18 @@
 #!/bin/sh
-# Script to test if gcc "-fwhole-program" works properly.
+# Script to test if the build works properly.
+
+# Test IASL is installed.
+$IASL -h > /dev/null 2>&1
+if [ $? -ne 0 ]; then
+    echo "The SeaBIOS project requires the 'iasl' package be installed." >&2
+    echo "Many Linux distributions have this package." >&2
+    echo "Try: sudo yum install iasl" >&2
+    echo "Or: sudo apt-get install iasl" >&2
+    echo "" >&2
+    echo "Please install iasl and retry." >&2
+    echo -1
+    exit 0
+fi
 
 mkdir -p out
 TMPFILE1=out/tmp_testcompile1.c
-- 
1.7.6.5




More information about the SeaBIOS mailing list